@@ -14,4 +14,5 @@
 #' @source The Zlatibor dataset was kindly provided by Prof. Branislav Bajat
 #'  from the University of Belgrade, Serbia.
 #'  
-"dem30m"
\ No newline at end of file
+#' @name dem30m
+NULL
\ No newline at end of file
